@@ -256,7 +256,7 @@ module Bio
         # Parses the first line of the BLAST result.
         def format0_parse_header
           unless defined?(@program)
-            if /([\-\w]+) +([\w\-\.\d]+) *\[ *([\-\.\w]+) *\] *(\[.+\])?/ =~ @f0header.to_s
+            if /([\-\w]+) +([\w\-\.]+) *\[ *([\-\.\w]+) *\] *(\[.+\])?/ =~ @f0header.to_s
               @program = $1
               @version = "#{$1} #{$2} [#{$3}]"
               @version_number = $2
@@ -384,10 +384,17 @@ module Bio
 
           # Returns name of the matrix.
           def matrix;      parse_params; @matrix;      end
+
           # Returns the match score of the matrix.
-          def sc_match;    parse_params; @sc_match;    end
+          def sc_match
+            parse_params
+            (defined? @sc_match) ? @sc_match : nil
+          end
           # Returns the mismatch score of the matrix.
-          def sc_mismatch; parse_params; @sc_mismatch; end
+          def sc_mismatch
+            parse_params
+            (defined? @sc_mismatch) ? @sc_mismatch : nil
+          end
 
           # Returns gap open penalty value.
           def gap_open;    parse_params; @gap_open;    end
@@ -571,7 +578,9 @@ module Bio
           # Returns nil if it is not a PHI-BLAST result.
           def pattern
             #PHI-BLAST
-            if !defined?(@pattern) and defined?(@pattern_in_database) then
+            if defined? @pattern
+              @pattern
+            elsif defined? @pattern_in_database then
               @pattern = nil
               @pattern_positions = []
               @f0message.each do |r|
@@ -582,8 +591,10 @@ module Bio
                   @pattern_positions << sc[1].to_i
                 end
               end
+              @pattern
+            else
+              nil
             end
-            @pattern
           end
 
           # (PHI-BLAST) Returns pattern positions.
@@ -662,7 +673,7 @@ module Bio
                     y = b[j]; y.strip!
                     y.reverse!
                     z = y.split(/\s+/, 3)
-                    z.each { |y| y.reverse! }
+                    z.each { |yy| yy.reverse! }
                     h = Hit.new([ z.pop.to_s.sub(/\.+\z/, '') ])
                     bs = z.pop.to_s
                     bs = '1' + bs if bs[0] == ?e
@@ -1043,7 +1054,7 @@ module Bio
           # Defines attributes which call parse_score before accessing.
           def self.method_after_parse_score(*names)
             names.each do |x|
-              module_eval("def #{x}; parse_score; @#{x}; end")
+              module_eval("def #{x}; parse_score; (defined? @#{x}) ? @#{x} : nil; end")
             end
           end
           private_class_method :method_after_parse_score
