@@ -126,9 +126,9 @@ module Bio::Sequence::Format::NucFormatter
     def mol_type_embl
       if mt = molecule_type then
         mt
-      elsif f = (features or []).find { |f| f.feature == 'source' } and
-          q = f.qualifiers.find { |q| q.qualifier == 'mol_type' } then
-        q.value
+      elsif fe = (features or []).find { |f| f.feature == 'source' } and
+          qu = fe.qualifiers.find { |q| q.qualifier == 'mol_type' } then
+        qu.value
       else
         'NA'
       end
