@@ -1,4 +1,5 @@
 # coding: US-ASCII
+# frozen_string_literal: true
 #
 # = bio/db/gff.rb - GFF format class
 #
@@ -137,13 +138,13 @@ module Bio
 
         sc = StringScanner.new(attributes)
         attrs = []
-        token = ''
+        token = String.new
         while !sc.eos?
           if sc.scan(/[^\\\;\"]+/) then
             token.concat sc.matched
           elsif sc.scan(/\;/) then
             attrs.push token unless token.empty?
-            token = ''
+            token = String.new
           elsif sc.scan(/\"/) then
             origtext = sc.matched
             while !sc.eos?
@@ -690,22 +691,22 @@ module Bio
           sc = StringScanner.new(str)
           attr_pairs = []
           tokens = []
-          cur_token = ''
+          cur_token = String.new
           while !sc.eos?
             if sc.scan(/[^\\\;\"\s]+/) then
               cur_token.concat sc.matched
             elsif sc.scan(/\s+/) then
               tokens.push cur_token unless cur_token.empty?
-              cur_token = ''
+              cur_token = String.new
             elsif sc.scan(/\;/) then
               tokens.push cur_token unless cur_token.empty?
-              cur_token = ''
+              cur_token = String.new
               attr_pairs.push tokens
               tokens = []
             elsif sc.scan(/\"/) then
               tokens.push cur_token unless cur_token.empty?
-              cur_token = ''
-              freetext = ''
+              cur_token = String.new
+              freetext = String.new
               while !sc.eos?
                 if sc.scan(/[^\\\"]+/) then
                   freetext.concat sc.matched
@@ -999,10 +1000,15 @@ module Bio
           str.empty? ? '.' : str
         end
 
-        if URI.const_defined?(:Parser) then
+        if URI.const_defined?(:RFC2396_Parser) then
+          # (private) URI::Parser object for escape/unescape GFF3 columns
+          URI_PARSER = URI::RFC2396_Parser.new
+        elsif URI.const_defined?(:Parser) then
           # (private) URI::Parser object for escape/unescape GFF3 columns
           URI_PARSER = URI::Parser.new
+        end
 
+        if const_defined?(:URI_PARSER) then
           # (private) the same as URI::Parser#escape(str, unsafe)
           def _escape(str, unsafe)
             URI_PARSER.escape(str, unsafe)
