@@ -42,6 +42,11 @@ class PATHWAY < KEGGDB
   def orthologs_as_hash; super; end if false #dummy for RDoc
   alias orthologs orthologs_as_hash
 
+  include Common::DiseasesAsHash
+  # Returns a Hash of the disease ID and its definition
+  def diseases_as_hash; super; end if false #dummy for RDoc
+  alias diseases diseases_as_hash
+
   include Common::References
   # REFERENCE -- Returns contents of the REFERENCE records as an Array of
   # Bio::Reference objects.
@@ -122,17 +127,6 @@ class PATHWAY < KEGGDB
     lines_fetch('DISEASE')
   end
 
-  # Diseases described in the DISEASE lines.
-  # ---
-  # *Returns*:: Hash of disease ID and its definition
-  def diseases_as_hash
-    unless (defined? @diseases_as_hash) && @diseases_as_hash
-      @diseases_as_hash = strings_as_hash(diseases_as_strings)
-    end
-    @diseases_as_hash
-  end
-  alias diseases diseases_as_hash
-
   # Returns an Array of a database name and entry IDs in DBLINKS field.
   # ---
   # *Returns*:: Array containing String
