@@ -38,7 +38,6 @@ module Bio
                   "H01457  Diabetic retinopathy",
                   "H01459  Diabetic neuropathy",
                   "H01529  Avascular necrosis of femoral head",
-                  "H01709  Glucocorticoid-induced osteonecrosis",
                   "H02559  Microvascular complications of diabetes"]
 
       assert_equal(expected, @obj.diseases_as_strings)
@@ -49,7 +48,6 @@ module Bio
                   "H01457"=>"Diabetic retinopathy",
                   "H01459"=>"Diabetic neuropathy",
                   "H01529"=>"Avascular necrosis of femoral head",
-                  "H01709"=>"Glucocorticoid-induced osteonecrosis",
                   "H02559"=>"Microvascular complications of diabetes"}
       assert_equal(expected, @obj.diseases_as_hash)
     end
@@ -64,6 +62,7 @@ module Bio
                   "Dilpacimab: D11642",
                   "Emvododstat: D11890",
                   "Faricimab: D11516<JP/US>",
+                  "Ivonescimab: D12808",
                   "Navicixizumab: D11126",
                   "Pegaptanib: D05386",
                   "Ranibizumab: D05697<JP/US>",
@@ -74,29 +73,28 @@ module Bio
     end
 
     def test_networks_as_strings
-      expected = ["nt06124  Chemokine signaling (viruses)",
-                  "nt06164  Kaposi sarcoma-associated herpesvirus (KSHV)",
-                  "nt06219  JAK-STAT signaling",
-                  "nt06224  CXCR signaling",
-                  "nt06225  HIF-1 signaling",
-                  "nt06227  Nuclear receptor signaling",
+      expected = ["nt06219  JAK-STAT signaling (cancer)",
+                  "nt06225  HIF-1 signaling (cancer)",
+                  "nt06227  Nuclear receptor signaling (cancer)",
                   "nt06262  Pancreatic cancer",
                   "nt06264  Renal cell carcinoma",
                   "nt06360  Cushing syndrome",
                   "nt06526  MAPK signaling",
                   "nt06528  Calcium signaling",
                   "nt06530  PI3K signaling",
+                  "nt06542  HIF signaling",
                   "N00079  HIF-1 signaling pathway",
                   "N00080  Loss of VHL to HIF-1 signaling pathway",
                   "N00081  Mutation-inactivated VHL to HIF-1 signaling pathway",
                   "N00095  ERBB2-overexpression to EGF-Jak-STAT signaling pathway",
-                  "N00157  KSHV vGPCR to GNB/G-ERK signaling pathway",
                   "N00317  AhR signaling pathway",
                   "N01412  Metals to HTF-1 signaling pathway",
                   "N01592  GF-RTK-RAS-ERK signaling pathway",
                   "N01641  RTK-PLCG-ITPR signaling pathway",
                   "N01656  GF-RTK-PI3K signaling pathway",
-                  "N01658  GF-RTK-RAS-PI3K signaling pathway"]
+                  "N01658  GF-RTK-RAS-PI3K signaling pathway",
+                  "N01870  HIF-2A signaling pathway",
+                  "N01873  VHL mutation to HIF-2 signaling pathway"]
       assert_equal(expected, @obj.networks_as_strings)
     end
 
